@@ -58,7 +58,7 @@ VERB = 3
 
 modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 			(u'k>',u'(ko)ko',u'koko'),
-			(u'k>',u'(ruo)ko',u'ruoko'),
+			(u'k>',u'(.*uo)ko',u'ruoko'),
 			(u'kk',u'(.*k)kU',u'alku'),
 			(u'uku',u'(.*U)kU',u'luku'),
 			(u'k>',u'(..U)kU',u'tiuku'),
@@ -305,7 +305,7 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 			(u'rt',u'(.*Vr)tAA',u'juurtaa'),
 			(u'nt',u'(.*Vn)tAA',u'saksantaa'),
 			(u't',u'(.*V)tAA',u'vuotaa')]),
-	(u'huutaa', u'sw', [(u'nt',u'(.*Vn)tAA',u'huutaa'),
+	(u'huutaa', u'sw', [(u'nt',u'(.*Vn)tAA',u'alentaa'),
 			(u't',u'(.*V)tAA',u'huutaa')]),
 	(u'sukeltaa', u'sw', [(u'lt',u'(.*Vl)tAA',u'sukeltaa'),
 			  (u'rt',u'(.*Vr)tAA',u'musertaa'),
