@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2007-2008 Hannu Väisänen (Etunimi.Sukunimi@joensuu.fi
+# Copyright 2007-2009 Hannu Väisänen (Etunimi.Sukunimi@joensuu.fi
 # Program to generate lexicon files for Suomi-malaga Sukija edition.
 
 # This program is free software; you can redistribute it and/or modify
@@ -27,11 +27,13 @@ import voikkoutils
 import re
 import sys
 
+
 # Historical inflections in alphabetical order.
 historical = [
 	(u'aavistaa', u'sw', [(u'tt',u'(.*O)ittAA',u'kirjoittaa'),
 			      (u'tt',u'(.*O)ttAA',u'ammottaa'),
 			      (None,u'(.*t)AA',u'aavistaa'),
+			      (u'tt',u'(.*eUt)tAA',u'kuluttaa'),
 			      (u'tt',u'(.*[AeiU]t)tAA',u'alittaa'),
 			      (u't',u'(.*h)tAA',u'astahtaa')]),
 	(u'ahven',    u'ws', [(None,u'(.*CVC)',u'ahven')]),
@@ -62,7 +64,9 @@ historical = [
 			      (u'pp',u'(.*p)pi',u'sinappi'),
 			      (u't',u'(.*)ti',u'konvehti') ]),
         (u'bébé', u'-', [(None,u'(.*V)',u'bébé')]),
-        (u'haastaa', u'sw', [(None,u'(.*C)AA',u'haastaa')]),
+        (u'haastaa', u'sw', [(None,u'(.*Ct)AA',u'haastaa')]),
+	(u'hame', u'ws', [(u't',u'(..*CO)ite',u'osoite'),
+			  (u't',u'(..*CO)te',u'tiedote')]),
 	(u'hohtaa',  u'sw', [(u'tt',u'(.*t)tAA',u'heittää')]),
 	(u'huutaa', u'sw', [(u'nt',u'(.*Vn)tAA',u'alentaa'),
 			(u't',u'(.*V)tAA',u'huutaa')]),
@@ -81,6 +85,10 @@ historical = [
 			    (None,u'(.*so)fia',u'filosofia'),
 			    (None,u'(.*gra)fia',u'topografia')]),
         (u'koiras', u'ws', [(None,u'(.*A)s',u'koiras')]),
+	(u'kohota', u'ws', [(u'k',u'(.*ik)OtA',u'laota'),
+			    (u'k',u'(.*Vk)OtA',u'saota'),
+			    (u'>k',u'(hi|la)OtA',u'laota'),
+			    (u'>k',u'(C[AiU])OtA',u'saota')]),
 	(u'kulkija', u'-', [(None,u'(.*lo)gia',u'analogia'),
 			    (None,u'(.*so)fia',u'filosofia'),
 			    (None,u'(.*gra)fia',u'topografia')]),
@@ -92,6 +100,7 @@ historical = [
 	(u'kutiaa', u'-',  [(None,u'(.*Cia)a',u'kutiaa')]),
         (u'laittaa', u'sw', [(u'tt',u'(.*t)tAA',u'laittaa')]),
 	(u'lampi', u'-',   [(None,u'(.*kam)pi',u'lampi')]),
+	(u'lovi', u'sw',   [(None,u'(rips|sin)i',u'kiiski')]),
 	(u'nainen', u'-', [(None,u'(.*Co)rinen',u'allegorinen'),
 			   (None,u'(.*Co)finen',u'filosofinen'),
 			   (None,u'(.*Co)ginen',u'psykologinen'),
@@ -131,7 +140,8 @@ historical = [
 			     (None,u'(..*[^aeouyäö]o)vi',u'telefoni_vi'),
 		             (None,u'(..*gr)afi',u'biografi'),
 			     (None,u'(..*)adi',u'marinadi'),
-			     (None,u'(..*)idi',u'pyramidi')]),
+			     (None,u'(..*)idi',u'pyramidi'),
+			     (u't',u'(tä|äi)ti',u'äiti')]),
         (u'siivota', u'ws', [(None,u'(.*O)tA',u'siivota')]),
 	(u'sydän', u'-', [(None,u'(.*A)n',u'sydän')]),
         (u'taittaa', u'sw', [(u'tt',u'(.*t)tAA',u'taittaa')]),
@@ -140,24 +150,21 @@ historical = [
 	(u'uros', u'-', [(None,u'(.*)s',u'uros')]),
 	(u'terve', u'-',[(None,u'(.*)',u'terve')]),
 	(u'valmis',u'ws', [(None,u'(.*)is',u'valmis')]),
-	(u'vastaus', u'-', [(None,u'(..[^oö]*O)itUs',u'aivoitus'),
-			    (None,u'(..[^oö]*O)tUs',u'jaotus'),
+	(u'vastaus', u'-', [(None,u'(lootu)s',u'vastaus'),
+			    (None,u'(..*CO)itUs',u'aivoitus'),
+			    (None,u'(...*O)tUs',u'jaotus'),
 			    (None,u'(.*V)s',u'vastaus'),]),
 	(u'veranta', u'sw', [(u'nt',u'(.*n)tA',u'veranta')]),
 	(u'vieras',  u'ws', [(None,u'(.*[lr]iA)s',u'utelias'),
 			     (u'k',u'(.*mek)As',u'iäkäs'),
 			     (u'k',u'(.*k)As',u'varas')]),
 	(u'vihanta', u'sw', [(u'nt',u'(.*n)tA',u'vihanta')]),
-        (u'virkkaa', u'sw', [(u'kk',u'(.*k)kAA',u'jakaa')])
+        (u'virkkaa', u'sw', [(u'kk',u'(.*k)kAA',u'virkkaa')])
         ]
 
 classmap = historical
 classmap.extend(hfconv.modern_classmap)
 
-#          u"(?P<jaotus>OtUs)|" + \
-#          u"(?P<aivoitus>OitUs)|" + \
-#
-
 pattern = u"^(?P<alku>.*)(?:" + \
 	  u"(?P<keltainen>C[aouyäö]i?nen)|" + \
 	  u"(?P<symboli_ym>[^aeouyäö]o[dfglmnrv]i)|" + \
@@ -173,7 +180,7 @@ rx = re.compile(pattern, re.IGNORECASE)
 begin = u"(amerikan|jälleen|tiibetin|uudelleen).+"
 rx_begin = re.compile(begin, re.IGNORECASE)
 
-end = u".+(herkkä|pöllö|rämeä|valmis)"
+end = u".+(herkkä|pöllö|valmis)"
 rx_end = re.compile(end, re.IGNORECASE)
 
 
@@ -450,8 +457,12 @@ def handle_word(main_vocabulary,vocabulary_files,word):
 		if (rx_end.match(wordform) != None):
 #			print ("Ei tarvita: " + wordform)
 			continue
-		if (((wordform == u"ori")   and (jatko == u"risti")) or
-		    ((wordform == u'kampi') and (jatko == u'sampi'))):
+		# Joillakin sanoilla on sanastossa kaksi taivususkaavaa, Sukijassa
+		# taivutuskaavat on yhdistetty, ja toisen taivutuskaavan voi poistaa.
+		if ((wordform in [u'ori', u'ripsi', u'sini', u'täti', u'äiti']) and (jatko == u'risti')):
+#			print ("Ei tarvita: " + wordform)
+			continue
+		if  ((wordform == u'kampi') and (jatko == u'sampi')):
 #			print ("Ei tarvita: " + wordform)
 			continue
 		
@@ -488,16 +499,16 @@ def handle_word(main_vocabulary,vocabulary_files,word):
 		# Useimmat kolmitavuiset (i)nen-loppuiset sanat hyväksytään i:llisinä ja i:ttöminä.
 		# Esim. kelta(i)nen, hevo(i)nen.
 		#
-		if ((jatko == u"nainen") and (nsyl == 3) and
-		    (malaga_word_class in [u"nimisana", u"nimi_laatusana", u"laatusana"]) and
-		    (rx != None) and (d != None) and (d['keltainen'] != None) and
-		    (not (wordform in [u"armainen", u"lukunen", u"omainen", u"osanen", u"vastuinen"]))):
-			if (wordform[-4] == u"i"):
-				alku2 = alku[:-1]    # Keltainen => keltanen.
-			else:
-				alku2 = alku + u"i"  # Hevonen => hevoinen.
-			jatko2 = jatko
-			wordform2 = alku2 + u"nen"
+#		if ((jatko == u"nainen") and (nsyl == 3) and
+#		    (malaga_word_class in [u"nimisana", u"nimi_laatusana", u"laatusana"]) and
+#		    (rx != None) and (d != None) and (d['keltainen'] != None) and
+#		    (not (wordform in [u"armainen", u"lukunen", u"omainen", u"osanen", u"vastuinen"]))):
+##			if (wordform[-4] == u"i"):
+##				alku2 = alku[:-1]    # Keltainen => keltanen.
+##			else:
+##				alku2 = alku + u"i"  # Hevonen => hevoinen.
+##			jatko2 = jatko
+##			wordform2 = alku2 + u"nen"
 #			if (wordform[-4] == u"i"):
 #				alku = wordform[:-4]    # Keltainen => keltanen.
 #				jatko = u"punainen"
@@ -507,8 +518,8 @@ def handle_word(main_vocabulary,vocabulary_files,word):
 		#
 		# Korjataan alku- ja jatko-kenttien arvoja.
 		#
-		elif (jatko == u"rakentaa"):
-#		if (jatko == u"rakentaa"):
+#		elif (jatko == u"rakentaa"):
+		if (jatko == u"rakentaa"):
 			alku = wordform[:-4]
 
 		# Tulostetaan.
